
From: Jesse Barnes <jbarnes@engr.sgi.com>

This patch originally from Greg Banks.  Some parts of the tg3 driver depend
on PIO writes arriving in order.  This patch ensures that in two key places
using the new mmiowb macro.  This not only prevents bugs (the queues can be
corrupted), but is much faster than ensuring ordering using PIO reads
(which involve a few round trips to the target bus on some platforms).

Arthur has another patch that uses mmiowb in tg3 that he posted earlier as
well.

Signed-off-by: Greg Banks <gnb@sgi.com>
Signed-off-by: Jesse Barnes <jbarnes@sgi.com>
Signed-off-by: Andrew Morton <akpm@osdl.org>
---

 25-akpm/drivers/net/tg3.c |    2 ++
 1 files changed, 2 insertions(+)

diff -puN drivers/net/tg3.c~use-mmiowb-in-tg3c drivers/net/tg3.c
--- 25/drivers/net/tg3.c~use-mmiowb-in-tg3c	2004-10-28 01:19:59.835181696 -0700
+++ 25-akpm/drivers/net/tg3.c	2004-10-28 01:19:59.844180328 -0700
@@ -2746,6 +2746,7 @@ next_pkt_nopost:
 		tw32_rx_mbox(MAILBOX_RCV_JUMBO_PROD_IDX + TG3_64BIT_REG_LOW,
 			     sw_idx);
 	}
+	mmiowb();
 
 	return received;
 }
@@ -3193,6 +3194,7 @@ static int tg3_start_xmit(struct sk_buff
 		netif_stop_queue(dev);
 
 out_unlock:
+    	mmiowb();
 	spin_unlock_irqrestore(&tp->tx_lock, flags);
 
 	dev->trans_start = jiffies;
_
